@@ -20,7 +20,7 @@
 
 ***************************************************************************/
 
-//     zfuncs.h   version  v.3.5.1
+//     zfuncs.h   version  v.3.7
 
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -390,7 +390,7 @@ GdkPixbuf * gdk_pixbuf_rotate(GdkPixbuf *, double deg, int alfa = 0);      //  r
 typedef void image_cbfunc(char *file);                                     //  callback function for clicked thumbnail
 char * image_gallery(cchar *filez, cchar *action, int Nth = 1,             //  display image gallery window, navigate,
                             image_cbfunc ufunc = 0);                       //    do callback for clicked thumbnails
-void image_position(cchar *file, int &posn, int &count);                   //  get curr. image position, total image count
+int image_position(cchar *file, int *count = 0);                           //  get curr. image position, total image count
 int image_file_type(cchar *file);                                          //  determine if directory or image file type
 char * image_thumbfile(cchar *imagefile);                                  //  get thumbnail filespec, create if missing
 GdkPixbuf * image_thumbnail(cchar *imagefile, int size = 0);               //  get thumbnail pixbuf, create if missing
